wim package
===========

Submodules
----------

wim.wim module
--------------

.. automodule:: wim.wim
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: wim
    :members:
    :undoc-members:
    :show-inheritance:
